@@ -1,9 +1,18 @@
 //-----------------------------------------------------------------------------
-// Christian Herrmann, 2020
+// Copyright (C) Christian Herrmann, 2020
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
 //
-// This code is licensed to you under the terms of the GNU GPL, version 2 or,
-// at your option, any later version. See the LICENSE.txt file for the text of
-// the license.
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
 //-----------------------------------------------------------------------------
 // main code for HID collector aka IceHID by Iceman
 //-----------------------------------------------------------------------------
@@ -190,7 +199,7 @@ static uint32_t IceIOdemod(void) {
 
     size_t size = MIN(12000, BigBuf_max_traceLen());
 
-//    uint8_t *dest = BigBuf_malloc(size);
+//    uint8_t *dest = BigBuf_calloc(size);
     uint8_t *dest = BigBuf_get_addr();
 
     //fskdemod and get start index
@@ -234,7 +243,7 @@ static uint32_t IceHIDDemod(void) {
     // large enough to catch 2 sequences of largest format
 //    size_t size = 50 * 128 * 2;  // 12800 bytes
     size_t size = MIN(12800, BigBuf_max_traceLen());
-    //uint8_t *dest = BigBuf_malloc(size);
+    //uint8_t *dest = BigBuf_calloc(size);
     uint8_t *dest = BigBuf_get_addr();
 
     // FSK demodulator
@@ -354,21 +363,21 @@ void RunMod(void) {
 
         // since we steal 12800 from bigbuffer, no need to sample it.
         size_t size = MIN(28000, BigBuf_max_traceLen());
-        DoAcquisition_config(false, size);
+        DoAcquisition_config(false, size, true);
         res = IceHIDDemod();
         if (res == PM3_SUCCESS) {
             LED_A_OFF();
             continue;
         }
 
-        DoAcquisition_config(false, size);
+        DoAcquisition_config(false, size, true);
         res = IceAWIDdemod();
         if (res == PM3_SUCCESS) {
             LED_A_OFF();
             continue;
         }
 
-        DoAcquisition_config(false, size);
+        DoAcquisition_config(false, size, true);
         res = IceIOdemod();
         if (res == PM3_SUCCESS) {
             LED_A_OFF();
@@ -376,7 +385,7 @@ void RunMod(void) {
         }
 
         size = MIN(20000, BigBuf_max_traceLen());
-        DoAcquisition_config(false, size);
+        DoAcquisition_config(false, size, true);
         res = IceEM410xdemod();
         if (res == PM3_SUCCESS) {
             LED_A_OFF();
