@@ -54,7 +54,7 @@ typedef int (*get_func)(void *data);
 typedef struct {
     get_func get;
     void *data;
-    char buffer[5];
+    char buffer[7];
     size_t buffer_pos;
     int state;
     int line;
@@ -179,11 +179,16 @@ static int stream_get(stream_t *stream, json_error_t *error) {
             size_t i, count;
 
             count = utf8_check_first(c);
-            if (!count)
+            if (count == 0) {
                 goto out;
+            }
+
+            // whatif count == 1 ?!?
 
             assert(count >= 2);
+            assert(count <= 4);
 
+            // if count == 4 ,   i will become 5 and overflow.
             for (i = 1; i < count; i++)
                 stream->buffer[i] = stream->get(stream->data);
 
