@@ -1,27 +1,39 @@
 /*
-** $Id: ldblib.c,v 1.132.1.1 2013/04/12 18:48:47 roberto Exp roberto $
+** $Id: ldblib.c $
 ** Interface from Lua to its debug API
 ** See Copyright Notice in lua.h
 */
 
+#define ldblib_c
+#define LUA_LIB
+
+#include "lprefix.h"
+
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-#define ldblib_c
-#define LUA_LIB
-
 #include "lua.h"
 
 #include "lauxlib.h"
 #include "lualib.h"
 
 
-#define HOOKKEY "_HKEY"
+/*
+** The hook table at registry[HOOKKEY] maps threads to their current
+** hook function.
+*/
+static const char *const HOOKKEY = "_HOOKKEY";
 
+
+/*
+** If L1 != L, L1 can be in any state, and therefore there are no
+** guarantees about its stack space; any push in L1 must be
+** checked.
+*/
 static void checkstack(lua_State *L, lua_State *L1, int n) {
-    if (L != L1 && !lua_checkstack(L1, n))
+    if (l_unlikely(L != L1 && !lua_checkstack(L1, n)))
         luaL_error(L, "stack overflow");
 }
 
@@ -43,8 +55,7 @@ static int db_getmetatable(lua_State *L) {
 
 static int db_setmetatable(lua_State *L) {
     int t = lua_type(L, 2);
-    luaL_argcheck(L, t == LUA_TNIL || t == LUA_TTABLE, 2,
-                  "nil or table expected");
+    luaL_argexpected(L, t == LUA_TNIL || t == LUA_TTABLE, 2, "nil or table");
     lua_settop(L, 2);
     lua_setmetatable(L, 1);
     return 1;  /* return 1st argument */
@@ -52,88 +63,111 @@ static int db_setmetatable(lua_State *L) {
 
 
 static int db_getuservalue(lua_State *L) {
+    int n = (int)luaL_optinteger(L, 2, 1);
     if (lua_type(L, 1) != LUA_TUSERDATA)
-        lua_pushnil(L);
-    else
-        lua_getuservalue(L, 1);
+        luaL_pushfail(L);
+    else if (lua_getiuservalue(L, 1, n) != LUA_TNONE) {
+        lua_pushboolean(L, 1);
+        return 2;
+    }
     return 1;
 }
 
 
 static int db_setuservalue(lua_State *L) {
-    if (lua_type(L, 1) == LUA_TLIGHTUSERDATA)
-        luaL_argerror(L, 1, "full userdata expected, got light userdata");
+    int n = (int)luaL_optinteger(L, 3, 1);
     luaL_checktype(L, 1, LUA_TUSERDATA);
-    if (!lua_isnoneornil(L, 2))
-        luaL_checktype(L, 2, LUA_TTABLE);
+    luaL_checkany(L, 2);
     lua_settop(L, 2);
-    lua_setuservalue(L, 1);
+    if (!lua_setiuservalue(L, 1, n))
+        luaL_pushfail(L);
     return 1;
 }
 
 
-static void settabss(lua_State *L, const char *i, const char *v) {
-    lua_pushstring(L, v);
-    lua_setfield(L, -2, i);
-}
-
-
-static void settabsi(lua_State *L, const char *i, int v) {
-    lua_pushinteger(L, v);
-    lua_setfield(L, -2, i);
-}
-
-
-static void settabsb(lua_State *L, const char *i, int v) {
-    lua_pushboolean(L, v);
-    lua_setfield(L, -2, i);
-}
-
-
+/*
+** Auxiliary function used by several library functions: check for
+** an optional thread as function's first argument and set 'arg' with
+** 1 if this argument is present (so that functions can skip it to
+** access their other arguments)
+*/
 static lua_State *getthread(lua_State *L, int *arg) {
     if (lua_isthread(L, 1)) {
         *arg = 1;
         return lua_tothread(L, 1);
     } else {
         *arg = 0;
-        return L;
+        return L;  /* function will operate over current thread */
     }
 }
 
 
-static void treatstackoption(lua_State *L, lua_State *L1, const char *fname) {
-    if (L == L1) {
-        lua_pushvalue(L, -2);
-        lua_remove(L, -3);
-    } else
-        lua_xmove(L1, L, 1);
-    lua_setfield(L, -2, fname);
+/*
+** Variations of 'lua_settable', used by 'db_getinfo' to put results
+** from 'lua_getinfo' into result table. Key is always a string;
+** value can be a string, an int, or a boolean.
+*/
+static void settabss(lua_State *L, const char *k, const char *v) {
+    lua_pushstring(L, v);
+    lua_setfield(L, -2, k);
+}
+
+static void settabsi(lua_State *L, const char *k, int v) {
+    lua_pushinteger(L, v);
+    lua_setfield(L, -2, k);
+}
+
+static void settabsb(lua_State *L, const char *k, int v) {
+    lua_pushboolean(L, v);
+    lua_setfield(L, -2, k);
 }
 
 
+/*
+** In function 'db_getinfo', the call to 'lua_getinfo' may push
+** results on the stack; later it creates the result table to put
+** these objects. Function 'treatstackoption' puts the result from
+** 'lua_getinfo' on top of the result table so that it can call
+** 'lua_setfield'.
+*/
+static void treatstackoption(lua_State *L, lua_State *L1, const char *fname) {
+    if (L == L1)
+        lua_rotate(L, -2, 1);  /* exchange object and table */
+    else
+        lua_xmove(L1, L, 1);  /* move object to the "main" stack */
+    lua_setfield(L, -2, fname);  /* put object into table */
+}
+
+
+/*
+** Calls 'lua_getinfo' and collects all results in a new table.
+** L1 needs stack space for an optional input (function) plus
+** two optional outputs (function and line table) from function
+** 'lua_getinfo'.
+*/
 static int db_getinfo(lua_State *L) {
     lua_Debug ar;
     int arg;
     lua_State *L1 = getthread(L, &arg);
-    const char *options = luaL_optstring(L, arg + 2, "flnStu");
+    const char *options = luaL_optstring(L, arg + 2, "flnSrtu");
     checkstack(L, L1, 3);
-    if (lua_isnumber(L, arg + 1)) {
-        if (!lua_getstack(L1, (int)lua_tointeger(L, arg + 1), &ar)) {
-            lua_pushnil(L);  /* level out of range */
+    luaL_argcheck(L, options[0] != '>', arg + 2, "invalid option '>'");
+    if (lua_isfunction(L, arg + 1)) {  /* info about a function? */
+        options = lua_pushfstring(L, ">%s", options);  /* add '>' to 'options' */
+        lua_pushvalue(L, arg + 1);  /* move function to 'L1' stack */
+        lua_xmove(L, L1, 1);
+    } else { /* stack level */
+        if (!lua_getstack(L1, (int)luaL_checkinteger(L, arg + 1), &ar)) {
+            luaL_pushfail(L);  /* level out of range */
             return 1;
         }
-    } else if (lua_isfunction(L, arg + 1)) {
-        lua_pushfstring(L, ">%s", options);
-        options = lua_tostring(L, -1);
-        lua_pushvalue(L, arg + 1);
-        lua_xmove(L, L1, 1);
-    } else
-        return luaL_argerror(L, arg + 1, "function or level expected");
+    }
     if (!lua_getinfo(L1, options, &ar))
         return luaL_argerror(L, arg + 2, "invalid option");
-    lua_createtable(L, 0, 2);
+    lua_newtable(L);  /* table to collect results */
     if (strchr(options, 'S')) {
-        settabss(L, "source", ar.source);
+        lua_pushlstring(L, ar.source, ar.srclen);
+        lua_setfield(L, -2, "source");
         settabss(L, "short_src", ar.short_src);
         settabsi(L, "linedefined", ar.linedefined);
         settabsi(L, "lastlinedefined", ar.lastlinedefined);
@@ -150,6 +184,10 @@ static int db_getinfo(lua_State *L) {
         settabss(L, "name", ar.name);
         settabss(L, "namewhat", ar.namewhat);
     }
+    if (strchr(options, 'r')) {
+        settabsi(L, "ftransfer", ar.ftransfer);
+        settabsi(L, "ntransfer", ar.ntransfer);
+    }
     if (strchr(options, 't'))
         settabsb(L, "istailcall", ar.istailcall);
     if (strchr(options, 'L'))
@@ -163,25 +201,26 @@ static int db_getinfo(lua_State *L) {
 static int db_getlocal(lua_State *L) {
     int arg;
     lua_State *L1 = getthread(L, &arg);
-    lua_Debug ar;
-    const char *name;
-    int nvar = luaL_checkint(L, arg + 2); /* local-variable index */
+    int nvar = (int)luaL_checkinteger(L, arg + 2);  /* local-variable index */
     if (lua_isfunction(L, arg + 1)) {  /* function argument? */
         lua_pushvalue(L, arg + 1);  /* push function */
         lua_pushstring(L, lua_getlocal(L, NULL, nvar));  /* push local name */
-        return 1;
+        return 1;  /* return only name (there is no value) */
     } else { /* stack-level argument */
-        if (!lua_getstack(L1, luaL_checkint(L, arg + 1), &ar)) /* out of range? */
+        lua_Debug ar;
+        const char *name;
+        int level = (int)luaL_checkinteger(L, arg + 1);
+        if (l_unlikely(!lua_getstack(L1, level, &ar)))  /* out of range? */
             return luaL_argerror(L, arg + 1, "level out of range");
         checkstack(L, L1, 1);
         name = lua_getlocal(L1, &ar, nvar);
         if (name) {
-            lua_xmove(L1, L, 1);  /* push local value */
+            lua_xmove(L1, L, 1);  /* move local value */
             lua_pushstring(L, name);  /* push name */
-            lua_pushvalue(L, -2);  /* re-order */
+            lua_rotate(L, -2, 1);  /* re-order */
             return 2;
         } else {
-            lua_pushnil(L);  /* no name (nor value) */
+            luaL_pushfail(L);  /* no name (nor value) */
             return 1;
         }
     }
@@ -190,27 +229,36 @@ static int db_getlocal(lua_State *L) {
 
 static int db_setlocal(lua_State *L) {
     int arg;
+    const char *name;
     lua_State *L1 = getthread(L, &arg);
     lua_Debug ar;
-    if (!lua_getstack(L1, luaL_checkint(L, arg + 1), &ar)) /* out of range? */
+    int level = (int)luaL_checkinteger(L, arg + 1);
+    int nvar = (int)luaL_checkinteger(L, arg + 2);
+    if (l_unlikely(!lua_getstack(L1, level, &ar)))  /* out of range? */
         return luaL_argerror(L, arg + 1, "level out of range");
     luaL_checkany(L, arg + 3);
     lua_settop(L, arg + 3);
     checkstack(L, L1, 1);
     lua_xmove(L, L1, 1);
-    lua_pushstring(L, lua_setlocal(L1, &ar, luaL_checkint(L, arg + 2)));
+    name = lua_setlocal(L1, &ar, nvar);
+    if (name == NULL)
+        lua_pop(L1, 1);  /* pop value (if not popped by 'lua_setlocal') */
+    lua_pushstring(L, name);
     return 1;
 }
 
 
+/*
+** get (if 'get' is true) or set an upvalue from a closure
+*/
 static int auxupvalue(lua_State *L, int get) {
     const char *name;
-    int n = luaL_checkint(L, 2);
-    luaL_checktype(L, 1, LUA_TFUNCTION);
+    int n = (int)luaL_checkinteger(L, 2);  /* upvalue index */
+    luaL_checktype(L, 1, LUA_TFUNCTION);  /* closure */
     name = get ? lua_getupvalue(L, 1, n) : lua_setupvalue(L, 1, n);
     if (name == NULL) return 0;
     lua_pushstring(L, name);
-    lua_insert(L, -(get + 1));
+    lua_insert(L, -(get + 1)); /* no-op if get is false */
     return get + 1;
 }
 
@@ -226,27 +274,37 @@ static int db_setupvalue(lua_State *L) {
 }
 
 
-static int checkupval(lua_State *L, int argf, int argnup) {
-    lua_Debug ar;
-    int nup = luaL_checkint(L, argnup);
-    luaL_checktype(L, argf, LUA_TFUNCTION);
-    lua_pushvalue(L, argf);
-    lua_getinfo(L, ">u", &ar);
-    luaL_argcheck(L, 1 <= nup && nup <= ar.nups, argnup, "invalid upvalue index");
-    return nup;
+/*
+** Check whether a given upvalue from a given closure exists and
+** returns its index
+*/
+static void *checkupval(lua_State *L, int argf, int argnup, int *pnup) {
+    void *id;
+    int nup = (int)luaL_checkinteger(L, argnup);  /* upvalue index */
+    luaL_checktype(L, argf, LUA_TFUNCTION);  /* closure */
+    id = lua_upvalueid(L, argf, nup);
+    if (pnup) {
+        luaL_argcheck(L, id != NULL, argnup, "invalid upvalue index");
+        *pnup = nup;
+    }
+    return id;
 }
 
 
 static int db_upvalueid(lua_State *L) {
-    int n = checkupval(L, 1, 2);
-    lua_pushlightuserdata(L, lua_upvalueid(L, 1, n));
+    void *id = checkupval(L, 1, 2, NULL);
+    if (id != NULL)
+        lua_pushlightuserdata(L, id);
+    else
+        luaL_pushfail(L);
     return 1;
 }
 
 
 static int db_upvaluejoin(lua_State *L) {
-    int n1 = checkupval(L, 1, 2);
-    int n2 = checkupval(L, 3, 4);
+    int n1, n2;
+    checkupval(L, 1, 2, &n1);
+    checkupval(L, 3, 4, &n2);
     luaL_argcheck(L, !lua_iscfunction(L, 1), 1, "Lua function expected");
     luaL_argcheck(L, !lua_iscfunction(L, 3), 3, "Lua function expected");
     lua_upvaluejoin(L, 1, n1, 3, n2);
@@ -254,26 +312,29 @@ static int db_upvaluejoin(lua_State *L) {
 }
 
 
-#define gethooktable(L) luaL_getsubtable(L, LUA_REGISTRYINDEX, HOOKKEY)
-
-
+/*
+** Call hook function registered at hook table for the current
+** thread (if there is one)
+*/
 static void hookf(lua_State *L, lua_Debug *ar) {
     static const char *const hooknames[] =
     {"call", "return", "line", "count", "tail call"};
-    gethooktable(L);
+    lua_getfield(L, LUA_REGISTRYINDEX, HOOKKEY);
     lua_pushthread(L);
-    lua_rawget(L, -2);
-    if (lua_isfunction(L, -1)) {
-        lua_pushstring(L, hooknames[(int)ar->event]);
+    if (lua_rawget(L, -2) == LUA_TFUNCTION) {  /* is there a hook function? */
+        lua_pushstring(L, hooknames[(int)ar->event]);  /* push event name */
         if (ar->currentline >= 0)
-            lua_pushinteger(L, ar->currentline);
+            lua_pushinteger(L, ar->currentline);  /* push current line */
         else lua_pushnil(L);
         lua_assert(lua_getinfo(L, "lS", ar));
-        lua_call(L, 2, 0);
+        lua_call(L, 2, 0);  /* call hook function */
     }
 }
 
 
+/*
+** Convert a string mask (for 'sethook') into a bit mask
+*/
 static int makemask(const char *smask, int count) {
     int mask = 0;
     if (strchr(smask, 'c')) mask |= LUA_MASKCALL;
@@ -284,6 +345,9 @@ static int makemask(const char *smask, int count) {
 }
 
 
+/*
+** Convert a bit mask (for 'gethook') into a string mask
+*/
 static char *unmakemask(int mask, char *smask) {
     int i = 0;
     if (mask & LUA_MASKCALL) smask[i++] = 'c';
@@ -298,7 +362,7 @@ static int db_sethook(lua_State *L) {
     int arg, mask, count;
     lua_Hook func;
     lua_State *L1 = getthread(L, &arg);
-    if (lua_isnoneornil(L, arg + 1)) {
+    if (lua_isnoneornil(L, arg + 1)) { /* no hook? */
         lua_settop(L, arg + 1);
         func = NULL;
         mask = 0;
@@ -306,22 +370,23 @@ static int db_sethook(lua_State *L) {
     } else {
         const char *smask = luaL_checkstring(L, arg + 2);
         luaL_checktype(L, arg + 1, LUA_TFUNCTION);
-        count = luaL_optint(L, arg + 3, 0);
+        count = (int)luaL_optinteger(L, arg + 3, 0);
         func = hookf;
         mask = makemask(smask, count);
     }
-    if (gethooktable(L) == 0) {  /* creating hook table? */
-        lua_pushstring(L, "k");
+    if (!luaL_getsubtable(L, LUA_REGISTRYINDEX, HOOKKEY)) {
+        /* table just created; initialize it */
+        lua_pushliteral(L, "k");
         lua_setfield(L, -2, "__mode");  /** hooktable.__mode = "k" */
         lua_pushvalue(L, -1);
-        lua_setmetatable(L, -2);  /* setmetatable(hooktable) = hooktable */
+        lua_setmetatable(L, -2);  /* metatable(hooktable) = hooktable */
     }
     checkstack(L, L1, 1);
     lua_pushthread(L1);
-    lua_xmove(L1, L, 1);
-    lua_pushvalue(L, arg + 1);
-    lua_rawset(L, -3);  /* set new hook */
-    lua_sethook(L1, func, mask, count);  /* set hooks */
+    lua_xmove(L1, L, 1);  /* key (thread) */
+    lua_pushvalue(L, arg + 1);  /* value (hook function) */
+    lua_rawset(L, -3);  /* hooktable[L1] = new Lua hook */
+    lua_sethook(L1, func, mask, count);
     return 0;
 }
 
@@ -332,18 +397,21 @@ static int db_gethook(lua_State *L) {
     char buff[5];
     int mask = lua_gethookmask(L1);
     lua_Hook hook = lua_gethook(L1);
-    if (hook != NULL && hook != hookf)  /* external hook? */
+    if (hook == NULL) {  /* no hook? */
+        luaL_pushfail(L);
+        return 1;
+    } else if (hook != hookf) /* external hook? */
         lua_pushliteral(L, "external hook");
-    else {
-        gethooktable(L);
+    else {  /* hook table must exist */
+        lua_getfield(L, LUA_REGISTRYINDEX, HOOKKEY);
         checkstack(L, L1, 1);
         lua_pushthread(L1);
         lua_xmove(L1, L, 1);
-        lua_rawget(L, -2);   /* get hook */
+        lua_rawget(L, -2);   /* 1st result = hooktable[L1] */
         lua_remove(L, -2);  /* remove hook table */
     }
-    lua_pushstring(L, unmakemask(mask, buff));
-    lua_pushinteger(L, lua_gethookcount(L1));
+    lua_pushstring(L, unmakemask(mask, buff));  /* 2nd result = mask */
+    lua_pushinteger(L, lua_gethookcount(L1));  /* 3rd result = count */
     return 3;
 }
 
@@ -351,13 +419,13 @@ static int db_gethook(lua_State *L) {
 static int db_debug(lua_State *L) {
     for (;;) {
         char buffer[250];
-        luai_writestringerror("%s", "lua_debug> ");
-        if (fgets(buffer, sizeof(buffer), stdin) == 0 ||
+        lua_writestringerror("%s", "lua_debug> ");
+        if (fgets(buffer, sizeof(buffer), stdin) == NULL ||
                 strcmp(buffer, "cont\n") == 0)
             return 0;
         if (luaL_loadbuffer(L, buffer, strlen(buffer), "=(debug command)") ||
                 lua_pcall(L, 0, 0, 0))
-            luai_writestringerror("%s\n", lua_tostring(L, -1));
+            lua_writestringerror("%s\n", luaL_tolstring(L, -1, NULL));
         lua_settop(L, 0);  /* remove eventual returns */
     }
 }
@@ -370,13 +438,21 @@ static int db_traceback(lua_State *L) {
     if (msg == NULL && !lua_isnoneornil(L, arg + 1))  /* non-string 'msg'? */
         lua_pushvalue(L, arg + 1);  /* return it untouched */
     else {
-        int level = luaL_optint(L, arg + 2, (L == L1) ? 1 : 0);
+        int level = (int)luaL_optinteger(L, arg + 2, (L == L1) ? 1 : 0);
         luaL_traceback(L, L1, msg, level);
     }
     return 1;
 }
 
 
+static int db_setcstacklimit(lua_State *L) {
+    int limit = (int)luaL_checkinteger(L, 1);
+    int res = lua_setcstacklimit(L, limit);
+    lua_pushinteger(L, res);
+    return 1;
+}
+
+
 static const luaL_Reg dblib[] = {
     {"debug", db_debug},
     {"getuservalue", db_getuservalue},
@@ -394,6 +470,7 @@ static const luaL_Reg dblib[] = {
     {"setmetatable", db_setmetatable},
     {"setupvalue", db_setupvalue},
     {"traceback", db_traceback},
+    {"setcstacklimit", db_setcstacklimit},
     {NULL, NULL}
 };
 
