@@ -80,7 +80,7 @@ def send_proxmark_command(command):
         host_device = detect_proxmark_device()
 
         process = subprocess.Popen(
-            ["proxmark3", host_device],
+            ["proxmark3", "-p", host_device],
             stdin=subprocess.PIPE,
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
@@ -154,7 +154,7 @@ def authenticate_and_menu():
         print("3. Delete an AID")
         print("4. Format PICC")
         print("5. Show free memory")
-        print("6. Change keys")
+        print("6. Change Master and AID keys")
         print("7. Exit")
 
         choice = input("Enter your choice: ").strip()
@@ -241,6 +241,7 @@ def create_aid(key_type, key, com_mode):
     create_command = f"hf mfdes createapp -n 0 --aid {aid} --fid {iso_fid} --dstalgo {dstalgo} -t {key_type} -k {key} -m {com_mode} -a"
     response = send_proxmark_command(create_command)
     print(response)
+    print("\n.:: DESFire assigns all-zero keys to new applications by default. Keys can be modified via the main menu. ::.\n")
 
 def delete_aid(key_type, key, com_mode):
 
@@ -337,7 +338,8 @@ def list_files(aid, key_type, key, com_mode, aid_key_type, aid_key):
             print(f"{i}. {file_id}")
         return file_ids
     else:
-        print("No files found in this AID.")
+        print("No files found in this AID.\n")
+        print(response)
         return []
 
 def read_file(aid, key_type, key, com_mode, aid_key_type, aid_key):
@@ -352,17 +354,50 @@ def read_file(aid, key_type, key, com_mode, aid_key_type, aid_key):
     length_input = input("Enter length to read (e.g., 16 for 16 bytes, 64 for 64 bytes, default full read): ").strip() or "0"
     length_hex = format(int(length_input), '06X')  # Convert to 3-byte hex
 
+    text_only = input("Show only human-readable text? (y/N): ").strip().lower() == "y"
+
     read_command = f"hf mfdes read --aid {aid} --fid {file_id} -t {aid_key_type} -k {aid_key} " \
                    f"--offset {offset_hex} --length {length_hex} -m {com_mode}"
     response = send_proxmark_command(read_command)
 
-    # Extract and display file content
-    print("\nFile Data:")
-    for line in response.splitlines():
-        if re.search(r"\| [0-9A-Fa-f]{2} .* \|", line):  # Matches data table format
-            print(line)
+    if "authenticate error" in response.lower():
+        print("\nAuthentication Error")
+        return None
 
-    return response
+    if text_only:
+        all_chars = []
+        for line in response.splitlines():
+            # Regex looks for hex column. e.g. | 65 20 70 69 7A ... |
+            m = re.search(r"\|\s*([0-9A-Fa-f\s]+)\s*\|", line)
+            if not m:
+                continue
+
+            # Split hex into individual bytes
+            hex_blob = m.group(1).strip()
+            for token in hex_blob.split():
+                try:
+                    b = int(token, 16)  # Convert each byte or token into a number
+                except ValueError:
+                    continue
+                if b == 0:  # Stop at NULL
+                    break
+                # Check if byte falls in printable ASCII range
+                all_chars.append(chr(b) if 0x20 <= b <= 0x7E else '.')
+
+        if all_chars:
+            text = "".join(all_chars)
+            print("\nPlain text:\n")
+            print(text)
+        else:
+            print("\nNo printable text found in the response.")
+
+        return response
+    else:
+        print("\nFile Data:\n")
+        for line in response.splitlines():
+            if re.search(r"\| [0-9A-Fa-f]{2} .* \|", line):
+                print(line)
+        return response
 
 def create_file(aid, key_type, key, com_mode, aid_key_type, aid_key):
 
@@ -410,6 +445,11 @@ def write_to_file(aid, key_type, key, com_mode, aid_key_type, aid_key):
     file_size_command = f"hf mfdes getfilesettings --aid {aid} --fid {file_id} -t {aid_key_type} -k {aid_key} -m {com_mode}"
     response = send_proxmark_command(file_size_command)
 
+    # Check for authentication error
+    if "authenticate error" in response.lower():
+        print("\nAuthentication Error")
+        return None
+
     # Extract the file size from the response
     file_size_match = re.search(r"File size \(bytes\)... (\d+) / 0x([0-9A-Fa-f]+)", response)
     if not file_size_match:
