@@ -26,10 +26,13 @@ typedef enum {
     DICTIONARY_NONE = 0,
     DICTIONARY_MIFARE,
     DICTIONARY_T55XX,
-    DICTIONARY_ICLASS
+    DICTIONARY_ICLASS,
+    DICTIONARY_MIFARE_ULC,
+    DICTIONARY_MIFARE_ULAES,
 } Dictionary_t;
 
 int CmdFlashMem(const char *Cmd);
 int rdv4_get_signature(rdv40_validation_t *out);
 int rdv4_validate(rdv40_validation_t *mem);
+int rdv4_get_flash_pages64k(uint8_t *pages64k);
 #endif
