@@ -71,6 +71,10 @@ static char *GenerateFilename(iso14a_card_select_t *card, const char *prefix, co
         return NULL;
     }
     char *fptr = calloc(sizeof(char) * (strlen(prefix) + strlen(suffix)) + sizeof(card->uid) * 2 + 1,  sizeof(uint8_t));
+    if (fptr == NULL) {
+        PrintAndLogEx(WARNING, "Failed to allocate memory");
+        return NULL;
+    }
     strcpy(fptr, prefix);
     FillFileNameByUID(fptr, card->uid, suffix, card->uidlen);
     return fptr;
@@ -195,7 +199,7 @@ int read_fudan_uid(bool loop, bool verbose) {
             PrintAndLogEx(NORMAL, "");
         }
 
-    } while (loop && kbd_enter_pressed() == false);
+    } while (loop && (kbd_enter_pressed() == false));
 
 
     return PM3_SUCCESS;
@@ -320,7 +324,7 @@ static int CmdHFFudanDump(const char *Cmd) {
                 }
             } else {
                 PrintAndLogEx(NORMAL, "");
-                PrintAndLogEx(WARNING, "command execute timeout when trying to read block %2d", b);
+                PrintAndLogEx(WARNING, "command execution time out when trying to read block %2d", b);
             }
         }
 
@@ -340,8 +344,9 @@ static int CmdHFFudanDump(const char *Cmd) {
     // create filename if none was given
     if (strlen(dataFilename) < 1) {
         char *fptr = GenerateFilename(&card, "hf-fudan-", "-dump");
-        if (fptr == NULL)
+        if (fptr == NULL) {
             return PM3_ESOFT;
+        }
 
         strcpy(dataFilename, fptr);
         free(fptr);
@@ -404,14 +409,14 @@ static int CmdHFFudanWrBl(const char *Cmd) {
 
     PacketResponseNG resp;
     if (WaitForResponseTimeout(CMD_ACK, &resp, 1500) == false) {
-        PrintAndLogEx(FAILED, "Command execute timeout");
+        PrintAndLogEx(FAILED, "command execution time out");
         return PM3_ETIMEOUT;
     }
 
     uint8_t isok  = resp.oldarg[0] & 0xff;
     if (isok) {
         PrintAndLogEx(SUCCESS, "Write ( " _GREEN_("ok") " )");
-        PrintAndLogEx(HINT, "try `" _YELLOW_("hf fudan rdbl") "` to verify");
+        PrintAndLogEx(HINT, "Hint: Try `" _YELLOW_("hf fudan rdbl") "` to verify");
     } else {
         PrintAndLogEx(FAILED, "Write ( " _RED_("fail") " )");
     }
