@@ -67,7 +67,7 @@ static int decode_and_print_memory(uint16_t card_size, const uint8_t *input_buff
     // copy input buffer into newly allocated buffer, because the existing code mutates the data inside.
     uint8_t *data = calloc(card_size, sizeof(uint8_t));
     if (data == NULL) {
-        PrintAndLogEx(WARNING, "Cannot allocate memory");
+        PrintAndLogEx(WARNING, "Failed to allocate memory");
         return PM3_EMALLOC;
     }
     memcpy(data, input_buffer, card_size);
@@ -432,7 +432,7 @@ static int CmdLegicInfo(const char *Cmd) {
     // allocate receiver buffer
     uint8_t *data = calloc(card.cardsize, sizeof(uint8_t));
     if (data == NULL) {
-        PrintAndLogEx(WARNING, "Cannot allocate memory");
+        PrintAndLogEx(WARNING, "Failed to allocate memory");
         return PM3_EMALLOC;
     }
 
@@ -494,8 +494,8 @@ static int CmdLegicRdbl(const char *Cmd) {
 
     // allocate receiver buffer
     uint8_t *data = calloc(len, sizeof(uint8_t));
-    if (!data) {
-        PrintAndLogEx(WARNING, "Cannot allocate memory");
+    if (data == NULL) {
+        PrintAndLogEx(WARNING, "Failed to allocate memory");
         return PM3_EMALLOC;
     }
 
@@ -560,7 +560,7 @@ static int CmdLegicSim(const char *Cmd) {
     for (;;) {
         if (kbd_enter_pressed()) {
             SendCommandNG(CMD_BREAK_LOOP, NULL, 0);
-            PrintAndLogEx(DEBUG, "User aborted");
+            PrintAndLogEx(DEBUG, "Aborted via keyboard!");
             break;
         }
 
@@ -569,7 +569,7 @@ static int CmdLegicSim(const char *Cmd) {
         }
     }
 
-    PrintAndLogEx(HINT, "Try `" _YELLOW_("hf legic list") "` to view trace log");
+    PrintAndLogEx(HINT, "Hint: Try `" _YELLOW_("hf legic list") "` to view trace log");
     PrintAndLogEx(INFO, "Done!");
     return PM3_SUCCESS;
 }
@@ -642,6 +642,10 @@ static int CmdLegicWrbl(const char *Cmd) {
     PrintAndLogEx(SUCCESS, "Writing to tag to offset %i", offset);
 
     legic_packet_t *payload = calloc(1, sizeof(legic_packet_t) + dlen);
+    if (payload == NULL) {
+        PrintAndLogEx(WARNING, "Failed to allocate memory");
+        return PM3_EMALLOC;
+    }
     payload->offset = (offset & 0xFFFF);
     payload->iv = (IV & 0x7F);
     payload->len = dlen;
@@ -719,6 +723,10 @@ int legic_read_mem(uint32_t offset, uint32_t len, uint32_t iv, uint8_t *out, uin
     legic_chk_iv(&iv);
 
     legic_packet_t *payload = calloc(1, sizeof(legic_packet_t));
+    if (payload == NULL) {
+        PrintAndLogEx(WARNING, "Failed to allocate memory");
+        return PM3_EMALLOC;
+    }
     payload->offset = (offset & 0xFFFF);
     payload->iv = iv;
     payload->len = len;
@@ -773,17 +781,20 @@ int legic_print_type(uint32_t tagtype, uint8_t spaces) {
 }
 int legic_get_type(legic_card_select_t *card) {
 
-    if (card == NULL)
+    if (card == NULL) {
         return PM3_EINVARG;
+    }
 
     clearCommandBuffer();
     SendCommandNG(CMD_HF_LEGIC_INFO, NULL, 0);
     PacketResponseNG resp;
-    if (WaitForResponseTimeout(CMD_HF_LEGIC_INFO, &resp, 1500) == false)
+    if (WaitForResponseTimeout(CMD_HF_LEGIC_INFO, &resp, 1500) == false) {
         return PM3_ETIMEOUT;
+    }
 
-    if (resp.status != PM3_SUCCESS)
+    if (resp.status != PM3_SUCCESS) {
         return PM3_ESOFT;
+    }
 
     memcpy(card, resp.data.asBytes, sizeof(legic_card_select_t));
     return PM3_SUCCESS;
@@ -817,6 +828,10 @@ void legic_seteml(uint8_t *src, uint32_t offset, uint32_t numofbytes) {
         }
 
         legic_packet_t *payload = calloc(1, sizeof(legic_packet_t) + len);
+        if (payload == NULL) {
+            PrintAndLogEx(WARNING, "Failed to allocate memory");
+            return;
+        }
         payload->offset = i;
         payload->len = len;
         memcpy(payload->data, src + i, len);
@@ -889,6 +904,10 @@ static int CmdLegicDump(const char *Cmd) {
     PrintAndLogEx(SUCCESS, "Reading tag memory." NOLF);
 
     legic_packet_t *payload = calloc(1, sizeof(legic_packet_t));
+    if (payload == NULL) {
+        PrintAndLogEx(WARNING, "Failed to allocate memory");
+        return PM3_EMALLOC;
+    }
     payload->offset = 0;
     payload->iv = 0x55;
     payload->len = dumplen;
@@ -916,8 +935,8 @@ static int CmdLegicDump(const char *Cmd) {
 
     uint16_t readlen = resp.data.asDwords[0];
     uint8_t *data = calloc(readlen, sizeof(uint8_t));
-    if (!data) {
-        PrintAndLogEx(WARNING, "Fail, cannot allocate memory");
+    if (data == NULL) {
+        PrintAndLogEx(WARNING, "Failed to allocate memory");
         return PM3_EMALLOC;
     }
 
@@ -936,7 +955,7 @@ static int CmdLegicDump(const char *Cmd) {
         // 0x00 ^ MCC = MCC. Finding the end of used data is not part of this function.
         if (legic_xor(data, dumplen) == false) {
             PrintAndLogEx(FAILED, "Deobsfuscate failed, exiting...");
-            PrintAndLogEx(HINT, "Try running command without `--de` parameter");
+            PrintAndLogEx(HINT, "Hint: Try running command without `--de` parameter");
             free(data);
             return PM3_EFAILED;
         }
@@ -1004,7 +1023,7 @@ static int CmdLegicRestore(const char *Cmd) {
     if (shall_obsfuscate) {
         if (legic_xor(dump, card.cardsize) == false) {
             PrintAndLogEx(FAILED, "Obsfuscate failed, exiting...");
-            PrintAndLogEx(HINT, "Try running command without `--ob` parameter");
+            PrintAndLogEx(HINT, "Hint: Try running command without `--ob` parameter");
             free(dump);
             return PM3_EFAILED;
         }
@@ -1027,6 +1046,11 @@ static int CmdLegicRestore(const char *Cmd) {
         }
 
         legic_packet_t *payload = calloc(1, sizeof(legic_packet_t) + len);
+        if (payload == NULL) {
+            PrintAndLogEx(WARNING, "Failed to allocate memory");
+            free(dump);
+            return PM3_EMALLOC;
+        }
         payload->offset = i;
         payload->iv = 0x55;
         payload->len = len;
@@ -1109,7 +1133,7 @@ static int CmdLegicELoad(const char *Cmd) {
 
     free(dump);
 
-    PrintAndLogEx(HINT, "You are ready to simulate. See " _YELLOW_("`hf legic sim -h`"));
+    PrintAndLogEx(HINT, "Hint: You are ready to simulate. See `" _YELLOW_("hf legic sim -h") "`");
     PrintAndLogEx(SUCCESS, "Done!");
     return PM3_SUCCESS;
 }
@@ -1163,7 +1187,7 @@ static int CmdLegicESave(const char *Cmd) {
     // set up buffer
     uint8_t *data = calloc(numofbytes, sizeof(uint8_t));
     if (data == NULL) {
-        PrintAndLogEx(WARNING, "Fail, cannot allocate memory");
+        PrintAndLogEx(WARNING, "Failed to allocate memory");
         return PM3_EMALLOC;
     }
 
@@ -1232,7 +1256,7 @@ static int CmdLegicEView(const char *Cmd) {
 
     uint8_t *dump = calloc(bytes, sizeof(uint8_t));
     if (dump == NULL) {
-        PrintAndLogEx(WARNING, "Fail, cannot allocate memory");
+        PrintAndLogEx(WARNING, "Failed to allocate memory");
         return PM3_EMALLOC;
     }
 
@@ -1296,7 +1320,7 @@ static int CmdLegicEInfo(const char *Cmd) {
 
     uint8_t *dump = calloc(card_size, sizeof(uint8_t));
     if (dump == NULL) {
-        PrintAndLogEx(WARNING, "Fail, cannot allocate memory");
+        PrintAndLogEx(WARNING, "Failed to allocate memory");
         return PM3_EMALLOC;
     }
 
@@ -1336,8 +1360,8 @@ static int CmdLegicWipe(const char *Cmd) {
 
     // set up buffer
     uint8_t *data = calloc(card.cardsize, sizeof(uint8_t));
-    if (!data) {
-        PrintAndLogEx(WARNING, "Fail, cannot allocate memory");
+    if (data == NULL) {
+        PrintAndLogEx(WARNING, "Failed to allocate memory");
         return PM3_EMALLOC;
     }
 
@@ -1360,6 +1384,11 @@ static int CmdLegicWipe(const char *Cmd) {
         }
 
         legic_packet_t *payload = calloc(1, sizeof(legic_packet_t) + len);
+        if (payload == NULL) {
+            PrintAndLogEx(WARNING, "Failed to allocate memory");
+            free(data);
+            return PM3_EMALLOC;
+        }
         payload->offset = i;
         payload->iv = 0x55;
         payload->len = len;
@@ -1501,7 +1530,7 @@ int readLegicUid(bool loop, bool verbose) {
         PrintAndLogEx(SUCCESS, " MSN: " _GREEN_("%s"), sprint_hex(card.uid + 1, sizeof(card.uid) - 1));
         legic_print_type(card.cardsize, 0);
 
-    } while (loop && kbd_enter_pressed() == false);
+    } while (loop && (kbd_enter_pressed() == false));
 
     return PM3_SUCCESS;
 }
