@@ -58,6 +58,8 @@ static const char *getHitagTypeStr(uint32_t uid) {
             return "PCF 7941";
         case 7:
             return "PCF 7952";
+        case 8:
+            return "PCF 7961";
         case 9:
             return "PCF 7945";
         default:
@@ -498,7 +500,7 @@ static int ht2_check_dictionary(uint32_t key_count, uint8_t *keys,  uint8_t keyl
 
         if (kbd_enter_pressed()) {
             SendCommandNG(CMD_BREAK_LOOP, NULL, 0);
-            PrintAndLogEx(INFO, "User aborted");
+            PrintAndLogEx(WARNING, "\naborted via keyboard!");
             break;
         }
 
@@ -912,7 +914,7 @@ static int CmdLFHitagReader(const char *Cmd) {
         if (ht2_get_uid(&uid)) {
             PrintAndLogEx(SUCCESS, "UID.... " _GREEN_("%08X"), uid);
         }
-    } while (cm && kbd_enter_pressed() == false);
+    } while (cm && (kbd_enter_pressed() == false));
 
     return PM3_SUCCESS;
 }
@@ -2428,8 +2430,8 @@ int ht2_read_uid(void) {
         return PM3_ESOFT;
     }
 
-    PrintAndLogEx(SUCCESS, "UID.... " _GREEN_("%08X"), uid);
-    PrintAndLogEx(SUCCESS, "TYPE... " _GREEN_("%s"), getHitagTypeStr(uid));
+    PrintAndLogEx(SUCCESS, "UID....... " _GREEN_("%08X"), uid);
+    PrintAndLogEx(SUCCESS, "TYPE...... " _GREEN_("%s"), getHitagTypeStr(uid));
     return PM3_SUCCESS;
 }
 
