@@ -632,7 +632,7 @@ static int CmdIndalaReader(const char *Cmd) {
     do {
         lf_read(false, 30000);
         demodIndalaEx(clk, invert, max_err, !cm);
-    } while (cm && !kbd_enter_pressed());
+    } while (cm & (kbd_enter_pressed() == false));
     return PM3_SUCCESS;
 }
 
@@ -1163,12 +1163,12 @@ int getIndalaBits(uint8_t fc, uint16_t cn, uint8_t *bits) {
     chk += ((cn >> 2) & 1); //y14 == 89 - 30 = 59
     chk += (cn & 1); //y16 == 71 - 30 = 41
 
-    if ((chk & 1) == 0) {
-        bits[62] = 0;
-        bits[63] = 1;
-    } else {
+    if ((chk & 1) == 0) { // If the sum is even, checksum is '10' (binary) = 2.
         bits[62] = 1;
         bits[63] = 0;
+    } else {              // If the sum is odd, checksum is '01' (binary) = 1.
+        bits[62] = 0;
+        bits[63] = 1;
     }
 
     // add parity
