@@ -179,7 +179,7 @@ static int CmdMotorolaReader(const char *Cmd) {
         // 64 * 32 * 2 * n-ish
         lf_read(false, 5000);
         res = demodMotorola(!cm);
-    } while (cm && !kbd_enter_pressed());
+    } while (cm && (kbd_enter_pressed() == false));
 
     // reset back to 125 kHz
     sc.divisor = LF_DIVISOR_125;
@@ -253,8 +253,8 @@ static int CmdMotorolaClone(const char *Cmd) {
     } else {
         res = clone_t55xx_tag(blocks, ARRAYLEN(blocks));
     }
-    PrintAndLogEx(SUCCESS, "Done");
-    PrintAndLogEx(HINT, "Hint: try " _YELLOW_("`lf motorola reader`") " to verify");
+    PrintAndLogEx(SUCCESS, "Done!");
+    PrintAndLogEx(HINT, "Hint: Try " _YELLOW_("`lf motorola reader`") " to verify");
     return res;
 }
 
