@@ -48,6 +48,7 @@
 #include "commonutil.h"   // ARRAYLEN
 #include "preferences.h"
 #include "cliparser.h"
+#include "cmdmqtt.h"
 
 static int CmdHelp(const char *Cmd);
 
@@ -59,6 +60,12 @@ static void AppendDate(char *s, size_t slen, const char *fmt) {
 #else
     ct = gmtime_r(&now, &tm_buf);
 #endif
+    if (ct == NULL) {
+        PrintAndLogEx(WARNING, "gmtime failed");
+        return;
+    }
+
+    // If no format is specified, use ISO8601
     if (fmt == NULL)
         strftime(s, slen, "%Y-%m-%dT%H:%M:%SZ", ct);  // ISO8601
     else
@@ -332,6 +339,7 @@ static command_t CommandTable[] = {
     {"hw",           CmdHW,        AlwaysAvailable,         "{ Hardware commands... }"},
     {"lf",           CmdLF,        AlwaysAvailable,         "{ Low frequency commands... }"},
     {"mem",          CmdFlashMem,  IfPm3Flash,              "{ Flash memory manipulation... }"},
+    {"mqtt",         CmdMqtt,      AlwaysAvailable,         "{ MQTT commmands... }"},
     {"nfc",          CmdNFC,       AlwaysAvailable,         "{ NFC commands... }"},
     {"piv",          CmdPIV,       AlwaysAvailable,         "{ PIV commands... }"},
     {"reveng",       CmdRev,       AlwaysAvailable,         "{ CRC calculations from RevEng software... }"},
