@@ -24,6 +24,6 @@
 int CmdTrace(const char *Cmd);
 int CmdTraceList(const char *Cmd);
 int CmdTraceListAlias(const char *Cmd, const char *alias, const char *protocol);
-bool ImportTraceBuffer(uint8_t *trace_src, uint16_t trace_len);
+bool ImportTraceBuffer(const uint8_t *trace_src, uint16_t trace_len);
 
 #endif
