@@ -44,7 +44,7 @@ typedef struct {
 int flash_load(flash_file_t *ctx, bool force);
 int flash_prepare(flash_file_t *ctx, int can_write_bl, int flash_size);
 int flash_start_flashing(int enable_bl_writes, char *serial_port_name, uint32_t *max_allowed);
-int flash_reboot_bootloader(char *serial_port_name);
+int flash_reboot_bootloader(char *serial_port_name, bool wait_appear);
 int flash_write(flash_file_t *ctx);
 void flash_free(flash_file_t *ctx);
 int flash_stop_flashing(void);
