@@ -51,6 +51,7 @@ const static vocabulary_t vocabulary[] = {
     { 1, "prefs get hints" },
     { 1, "prefs get output" },
     { 1, "prefs get plotsliders" },
+    { 1, "prefs get mqtt" },
     { 1, "prefs set help" },
     { 1, "prefs set barmode" },
     { 1, "prefs set client.debug" },
@@ -62,6 +63,7 @@ const static vocabulary_t vocabulary[] = {
     { 1, "prefs set savepaths" },
     { 1, "prefs set output" },
     { 1, "prefs set plotsliders" },
+    { 1, "prefs set mqtt" },
     { 1, "analyse help" },
     { 1, "analyse lrc" },
     { 1, "analyse crc" },
@@ -240,6 +242,7 @@ const static vocabulary_t vocabulary[] = {
     { 0, "hf felica reader" },
     { 0, "hf felica sniff" },
     { 0, "hf felica wrbl" },
+    { 0, "hf felica dump" },
     { 0, "hf felica rqservice" },
     { 0, "hf felica rqresponse" },
     { 0, "hf felica scsvcode" },
@@ -249,6 +252,7 @@ const static vocabulary_t vocabulary[] = {
     { 0, "hf felica rqspecver" },
     { 0, "hf felica resetmode" },
     { 0, "hf felica litesim" },
+    { 0, "hf felica liteauth" },
     { 0, "hf felica litedump" },
     { 1, "hf fido help" },
     { 1, "hf fido list" },
@@ -496,6 +500,16 @@ const static vocabulary_t vocabulary[] = {
     { 0, "hf ntag424 getfs" },
     { 0, "hf ntag424 changefs" },
     { 0, "hf ntag424 changekey" },
+    { 1, "hf saflok help" },
+    { 0, "hf saflok read" },
+    { 0, "hf saflok provision" },
+    { 1, "hf saflok encode" },
+    { 1, "hf saflok decode" },
+    { 1, "hf saflok modify" },
+    { 1, "hf saflok encrypt" },
+    { 1, "hf saflok decrypt" },
+    { 0, "hf saflok interrogate" },
+    { 0, "hf saflok cksum" },
     { 1, "hf seos help" },
     { 1, "hf seos list" },
     { 0, "hf seos sam" },
@@ -794,6 +808,7 @@ const static vocabulary_t vocabulary[] = {
     { 0, "lf t55xx restore" },
     { 1, "lf t55xx trace" },
     { 0, "lf t55xx wakeup" },
+    { 1, "lf t55xx view" },
     { 0, "lf t55xx write" },
     { 0, "lf t55xx bruteforce" },
     { 0, "lf t55xx chk" },
@@ -832,6 +847,9 @@ const static vocabulary_t vocabulary[] = {
     { 0, "mem spiffs upload" },
     { 0, "mem spiffs view" },
     { 0, "mem spiffs wipe" },
+    { 1, "mqtt help" },
+    { 1, "mqtt send" },
+    { 1, "mqtt receive" },
     { 1, "nfc help" },
     { 1, "nfc decode" },
     { 0, "nfc type1 read" },
