@@ -73,6 +73,7 @@ int kbd_enter_pressed(void) {
         c = getchar();
         ret |= c == '\n';
     } while (c != EOF);
+
     //blocking
     flags &= ~O_NONBLOCK;
     if (fcntl(STDIN_FILENO, F_SETFL, flags) < 0) {
@@ -1212,6 +1213,29 @@ void binstr_2_bytes(uint8_t *target, size_t *targetlen, const char *src) {
     }
 }
 
+void binstr_2_u8(char *src, uint8_t n, uint8_t *dest) {
+
+    uint8_t b = 0;
+    // Process binary string
+    for (uint8_t i = 0; i < n; ++i) {
+        b = (b << 1) | (src[i] == '1');
+    }
+    if (dest) {
+        *dest = b;
+    }
+}
+
+void binstr_2_u16(char *src, uint8_t n, uint16_t *dest) {
+    uint16_t b = 0;
+    // Process binary string
+    for (uint8_t i = 0; i < n; ++i) {
+        b = (b << 1) | (src[i] == '1');
+    }
+    if (dest) {
+        *dest = b;
+    }
+}
+
 void hex_xor(uint8_t *d, const uint8_t *x, int n) {
     while (n--) {
         d[n] ^= x[n];
@@ -1539,6 +1563,10 @@ int byte_strstr(const uint8_t *src, size_t srclen, const uint8_t *pattern, size_
             continue;
         }
 
+        if (plen == 1) {
+            return i;
+        }
+
         // try to match rest of the pattern
         for (int j = plen - 1; j >= 1; j--) {
 
@@ -1606,3 +1634,40 @@ uint8_t get_highest_frequency(const uint8_t *d, uint8_t n) {
     PrintAndLogEx(DEBUG, "highest occurance... %u  xor byte... 0x%02X", highest, v);
     return v;
 }
+
+size_t unduplicate(uint8_t *d, size_t n, const uint8_t item_n) {
+    if (n == 0) {
+        return 0;
+    }
+    if (n == 1) {
+        return 1;
+    }
+
+    int write_index = 0;
+
+    for (int read_index = 0; read_index < n; ++read_index) {
+        uint8_t *current = d + read_index * item_n;
+
+        bool is_duplicate = false;
+
+        // Check against all previous unique elements
+        for (int i = 0; i < write_index; ++i) {
+            uint8_t *unique = d + i * item_n;
+            if (memcmp(current, unique, item_n) == 0) {
+                is_duplicate = 1;
+                break;
+            }
+        }
+
+        // If not duplicate, move to the write_index position
+        if (is_duplicate == false) {
+            uint8_t *dest = d + write_index * item_n;
+            if (dest != current) {
+                memcpy(dest, current, item_n);
+            }
+            write_index++;
+        }
+    }
+
+    return write_index;
+}
