@@ -65,6 +65,21 @@
 #define REV64(x)        (REV32(x) + ((uint64_t)(REV32((x) >> 32) << 32)))
 #endif
 
+typedef struct {
+    int Year;
+    int Month;
+    int Day;
+    int Hour;
+    int Minute;
+} Date_t;
+
+
+int calculate_hours_between_dates(const Date_t s, Date_t *e);
+void add_minutes(Date_t *d, int minutes_to_add);
+void add_hours(Date_t *d, int hours_to_add);
+void add_days(Date_t *d, int days_to_add);
+uint8_t days_in_month(int year, int month);
+
 
 extern struct version_information_t g_version_information;
 void FormatVersionInformation(char *dst, int len, const char *prefix, const void *version_info);
@@ -72,9 +87,10 @@ void format_version_information_short(char *dst, int len, const void *version_in
 
 uint32_t reflect(uint32_t v, int b); // used in crc.c ...
 uint8_t reflect8(uint8_t b);         // dedicated 8bit reversal
-uint16_t reflect16(uint16_t b);      // dedicated 16bit reversal
-uint32_t reflect32(uint32_t b);      // dedicated 32bit reversal
-uint64_t reflect64(uint64_t b);      // dedicated 64bit reversal
+uint16_t reflect16(uint16_t v);      // dedicated 16bit reversal
+uint32_t reflect32(uint32_t v);      // dedicated 32bit reversal
+uint64_t reflect48(uint64_t v);      // dedicated 48bit reversal
+uint64_t reflect64(uint64_t v);      // dedicated 64bit reversal
 
 void num_to_bytes(uint64_t n, size_t len, uint8_t *dest);
 uint64_t bytes_to_num(const uint8_t *src, size_t len);
@@ -113,10 +129,16 @@ void Uint7byteToMemBe(uint8_t *data, uint64_t value);
 void Uint8byteToMemBe(uint8_t *data, uint64_t value);
 
 // rotate left byte array
-void rol(uint8_t *data, const size_t len);
-void ror(uint8_t *data, const size_t len);
+void rol(uint8_t *data, const size_t n);
+void ror(uint8_t *data, const size_t n);
+void xor(uint8_t *dest, const uint8_t *src, size_t n);
+
+void lsl(uint8_t *d, size_t n);
+void lslx(uint8_t *d, size_t n, uint8_t shifts);
+
+void rsl(uint8_t *d, size_t n);
+void rslx(uint8_t *d, size_t n, uint8_t shifts);
 
-void lsl(uint8_t *data, size_t len);
 uint32_t le24toh(const uint8_t data[3]);
 void htole24(uint32_t val, uint8_t data[3]);
 
@@ -132,5 +154,9 @@ void reverse_array_copy(const uint8_t *src, int src_len, uint8_t *dest);
 bool hexstr_to_byte_array(const char *hexstr, uint8_t *d, size_t *n);
 
 void reverse_arraybytes(uint8_t *arr, size_t len);
-void reverse_arraybytes_copy(uint8_t *arr, uint8_t *dest, size_t len);
+void reverse_arraybytes_copy(const uint8_t *arr, uint8_t *dest, size_t len);
+
+size_t concatbits(uint8_t *dest, int dest_offset, const uint8_t *src, int src_offset, size_t nbits, bool src_lsb);
+int char2int(char c);
+int hexstr2ByteArr(const char *hexstr, unsigned char *array, size_t asize);
 #endif
