@@ -33,6 +33,8 @@
  *
  */
 
+#pragma GCC diagnostic ignored "-Wunused-variable"
+
 #include "common.h"
 
 #if defined(MBEDTLS_BIGNUM_C)
@@ -1440,6 +1442,7 @@ __attribute__((noinline))
 #endif
 void mpi_mul_hlp(size_t i, mbedtls_mpi_uint *s, mbedtls_mpi_uint *d, mbedtls_mpi_uint b) {
     mbedtls_mpi_uint c = 0, t = 0;
+    (void)t;
 
 #if defined(MULADDC_HUIT)
     for (; i >= 8; i -= 8) {
