@@ -349,6 +349,12 @@ typedef struct {
     uint8_t key[6];
 } PACKED mfc_eload_t;
 
+typedef struct {
+    bool use_flashmem;
+    uint16_t keycount;
+    uint8_t keys[];
+} PACKED mfulc_keys_t;
+
 typedef struct {
     uint8_t status;
     uint8_t CSN[8];
@@ -761,7 +767,8 @@ typedef struct {
 #define CMD_HF_MFU_OTP_TEAROFF                                            0x0740
 // MFU_Ev1 Counter TearOff
 #define CMD_HF_MFU_COUNTER_TEAROFF                                        0x0741
-
+#define CMD_HF_MFU_ULC_CHKKEYS                                            0x0742
+#define CMD_HF_MFU_ULAES_CHKKEYS                                          0x0743
 
 
 #define CMD_HF_SNIFF                                                      0x0800
@@ -866,7 +873,7 @@ typedef struct {
 #define FLAG_NR_AR_ATTACK       0x0400
 // support nested authentication attack
 #define FLAG_NESTED_AUTH_ATTACK 0x0800
-
+#define FLAG_MF_ALLOW_OOB_AUTH  0x1000
 
 #define MODE_SIM_CSN        0
 #define MODE_EXIT_AFTER_MAC 1
@@ -958,6 +965,8 @@ typedef struct {
 // Cryptographic error                  client/pm3: cryptographic operation failed
 #define PM3_ECRYPTO           -29
 
+// File error                           client:     error related to file does not exist in search paths
+#define PM3_ENOFILE           -30
 // No data                              client/pm3: no data available, no host frame available (not really an error)
 #define PM3_ENODATA           -98
 // Quit program                         client:     reserved, order to quit the program
